.. _chronologisch:


.. raw:: html

    <br>
    <center>

chronologisch
=============

.. raw:: html

    </center>
    <br>

Ik ben Bart Thate, een 49 jarige schizofrenie patient. Het is voor mij niet mogelijk gebleken om :ref:`aangifte <aangifte>` te doen van mishandeling als de psychiater zijn patient met medicijnen mishandelt.

De IGZ treft geen structurele :ref:`onzorgvuldigheid <igz>` in de afhandeling van klachten bij GGZ-NHN aan.
De :ref:`Hoge Raad <hogeraad>` concludeert dat het geen verantwoordelijkheid heeft en verwijst naar het Openbaar Ministerie, dat niet reageert.
Daarna heb ik het Europeese Hof voor de Rechten van de Mens aangeschreven om een :ref:`klacht <greffe>` tegen Nederland in te dienen. 
De klacht betreft problemen met de invoering van de :ref:`(F)ACT <fact>` methodiek in Nederland. De :ref:`Koningin <beuker>` kan hier geen verder tussenkomst verlenen.
:ref:`Uitspraak <uitspraak>` is niet-ontvankelijk.

Pas na een gang langs het EVRM reageert Het :ref:`Openbaar Ministerie <om>` wel en verwijst naar de IGZ, die de klacht melding al heeft afgesloten. 

Ik concludeer hier uit dat het in Nederland voor de GGZ patient niet mogelijk is om aangifte te doen voor een strafbaar feit als een arts met gif mishandelt.

